# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/study/course/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Study\\Course\\": "packages/study/course/src",
            "Study\\Course\\Seeders\\": "packages/study/course/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Study\Course\Providers\CourseServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Course'  => Study\Course\Facades\Course::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Study\\Course\\Seeders\\CourseTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Study\Course\Providers\CourseServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Study\Course\Providers\CourseServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Study\Course\Providers\CourseServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/course/{modulename}

**User**

    http://path-to-route-folder/user/course/{modulename}

**Public**

    http://path-to-route-folder/courses


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/course/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/course/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/course/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/course/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/course/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/course/{modulename}/{slug}
    METHOD: GET