<?php

namespace Study\Course\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Study\Course\Interfaces\SubjectRepositoryInterface;
use Study\Course\Repositories\Eloquent\Filters\SubjectPublicFilter;
use Study\Course\Repositories\Eloquent\Presenters\SubjectListPresenter;

class SubjectPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        SubjectRepositoryInterface $subject
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('study.course.modules'), 'subject', guard_url('subject'));
        $this->repository = $subject;
    }

    /**
     * Show subject's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(SubjectPublicFilter::class)
            ->setPresenter(SubjectListPresenter::class)
            ->select('subjects.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('course::subject.names'))
            ->view('course::public.subject.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show subject.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('course::subject.name'))
            ->view('course::public.subject.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
