<?php

namespace Study\Course\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Study\Course\Interfaces\TopicRepositoryInterface;
use Study\Course\Repositories\Eloquent\Filters\TopicPublicFilter;
use Study\Course\Repositories\Eloquent\Presenters\TopicListPresenter;

class TopicPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        TopicRepositoryInterface $topic
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('study.course.modules'), 'topic', guard_url('topic'));
        $this->repository = $topic;
    }

    /**
     * Show topic's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(TopicPublicFilter::class)
            ->setPresenter(TopicListPresenter::class)
            ->select('topics.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('course::topic.names'))
            ->view('course::public.topic.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show topic.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('course::topic.name'))
            ->view('course::public.topic.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
