<?php

namespace Study\Course\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Study\Course\Models\Course;

class CoursePolicy
{

    /**
     * Determine if the given user can view the course.
     *
     * @param UserPolicyInterface $authUser
     * @param Course $course
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Course $course)
    {
        if ($authUser->canDo('course.course.view') && $authUser->isAdmin()) {
            return true;
        }

        return $course->user_id == user_id() && $course->user_type == user_type();
    }

    /**
     * Determine if the given user can create a course.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('course.course.create');
    }

    /**
     * Determine if the given user can update the given course.
     *
     * @param UserPolicyInterface $authUser
     * @param Course $course
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Course $course)
    {
        if ($authUser->canDo('course.course.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $course->user_id == user_id() && $course->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given course.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Course $course)
    {
        return $course->user_id == user_id() && $course->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given course.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Course $course)
    {
        if ($authUser->canDo('course.course.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given course.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Course $course)
    {
        if ($authUser->canDo('course.course.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
