<?php

namespace Study\Course\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Study\Course\Models\Subject;

class SubjectPolicy
{

    /**
     * Determine if the given user can view the subject.
     *
     * @param UserPolicyInterface $authUser
     * @param Subject $subject
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Subject $subject)
    {
        if ($authUser->canDo('course.subject.view') && $authUser->isAdmin()) {
            return true;
        }

        return $subject->user_id == user_id() && $subject->user_type == user_type();
    }

    /**
     * Determine if the given user can create a subject.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('course.subject.create');
    }

    /**
     * Determine if the given user can update the given subject.
     *
     * @param UserPolicyInterface $authUser
     * @param Subject $subject
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Subject $subject)
    {
        if ($authUser->canDo('course.subject.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $subject->user_id == user_id() && $subject->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given subject.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Subject $subject)
    {
        return $subject->user_id == user_id() && $subject->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given subject.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Subject $subject)
    {
        if ($authUser->canDo('course.subject.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given subject.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Subject $subject)
    {
        if ($authUser->canDo('course.subject.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
