<?php

namespace Study\Course\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Study\Course\Models\Topic;

class TopicPolicy
{

    /**
     * Determine if the given user can view the topic.
     *
     * @param UserPolicyInterface $authUser
     * @param Topic $topic
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Topic $topic)
    {
        if ($authUser->canDo('course.topic.view') && $authUser->isAdmin()) {
            return true;
        }

        return $topic->user_id == user_id() && $topic->user_type == user_type();
    }

    /**
     * Determine if the given user can create a topic.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('course.topic.create');
    }

    /**
     * Determine if the given user can update the given topic.
     *
     * @param UserPolicyInterface $authUser
     * @param Topic $topic
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Topic $topic)
    {
        if ($authUser->canDo('course.topic.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $topic->user_id == user_id() && $topic->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given topic.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Topic $topic)
    {
        return $topic->user_id == user_id() && $topic->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given topic.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Topic $topic)
    {
        if ($authUser->canDo('course.topic.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given topic.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Topic $topic)
    {
        if ($authUser->canDo('course.topic.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
