<?php

namespace Study\Course\Providers;

use Illuminate\Support\ServiceProvider;
use Study\Course\Courses;

class CourseServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'course');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'course');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Study\Course\Providers\AuthServiceProvider::class);
        $this->app->register(\Study\Course\Providers\RouteServiceProvider::class);
        // $this->app->register(\Study\Course\Providers\EventServiceProvider::class);
        // $this->app->register(\Study\Course\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('study.course', function($app)
        {
            return $this->app->make(Courses::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind Course to repository
        $this->app->bind(
            'Study\Course\Interfaces\CourseRepositoryInterface',
            \Study\Course\Repositories\Eloquent\CourseRepository::class
        );        // Bind Topic to repository
        $this->app->bind(
            'Study\Course\Interfaces\TopicRepositoryInterface',
            \Study\Course\Repositories\Eloquent\TopicRepository::class
        );        // Bind Subject to repository
        $this->app->bind(
            'Study\Course\Interfaces\SubjectRepositoryInterface',
            \Study\Course\Repositories\Eloquent\SubjectRepository::class
        );
    }


    /**
     * Merges user's and course's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'study.course'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Study\Course\Commands\Course::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['study.course'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('study/course.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/course')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/course')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
