<?php

namespace Study\Course\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Study\Course\Models\Course;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Study\Course\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/course/course/*')) {
            Route::bind('course', function ($course) {
                $courseRepo = $this->app->make('Study\Course\Interfaces\CourseRepositoryInterface');
                return $courseRepo->findorNew($course);
            });
        }
        if (Request::is('*/course/topic/*')) {
            Route::bind('topic', function ($topic) {
                $topicRepo = $this->app->make('Study\Course\Interfaces\TopicRepositoryInterface');
                return $topicRepo->findorNew($topic);
            });
        }
        if (Request::is('*/course/subject/*')) {
            Route::bind('subject', function ($subject) {
                $subjectRepo = $this->app->make('Study\Course\Interfaces\SubjectRepositoryInterface');
                return $subjectRepo->findorNew($subject);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
